/*
     SyphonImage.h
     Syphon
     
     Copyright 2010-2011 bangnoise (Tom Butterworth) & vade (Anton Marini).
     All rights reserved.
     
     Redistribution and use in source and binary forms, with or without
     modification, are permitted provided that the following conditions are met:
     
     * Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
     
     * Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
     
     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
     DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
     ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#import <Cocoa/Cocoa.h>
#import <OpenGL/OpenGL.h>

/** 
 SyphonImage represents an image stored as an OpenGL texture. In classic
 Syphon, the texture target is always GL_TEXTURE_RECTANGLE_ARB. But
 IzzySyphon has the option to publish either GL_TEXTURE_RECTANGLE_ARB
 or GL_TEXTURE_2D. So the textureTarget method was addeded to allow the
 receiver to determine the target for the texture.
 */

@interface SyphonImage : NSObject {

}

/**
 A GLenum representing the texture target.
 */
@property (readonly) GLuint textureTarget;

/**
 A GLuint representing the texture name.
 */
@property (readonly) GLuint textureName;

/**
 A NSSize representing the dimensions of the texture. The image will fill the texture entirely.
 */
@property (readonly) NSSize textureSize;

@end
